@@ -67,7 +67,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 __author__ = "Wai Yip Tung,  Findyou，Adil, Javen"
 __version__ = "0.8.2.3"
 
-
 """
 Change History
 Version 0.8.2.3 -Javen
@@ -109,6 +108,7 @@ import sys
 
 class OutputRedirector(object):
     """ Wrapper to redirect stdout or stderr """
+
     def __init__(self, fp):
         self.fp = fp
 
@@ -121,9 +121,11 @@ class OutputRedirector(object):
     def flush(self):
         self.fp.flush()
 
+
 stdout_redirector = OutputRedirector(sys.stdout)
 stderr_redirector = OutputRedirector(sys.stderr)
 
+
 # ----------------------------------------------------------------------
 # Template
 
@@ -168,10 +170,10 @@ class Template_mixin(object):
     """
 
     STATUS = {
-    0: '通过',
-    1: '失败',
-    2: '错误',
-    3: '跳过',
+        0: '通过',
+        1: '失败',
+        2: '错误',
+        3: '跳过',
     }
     # 默认测试标题
     DEFAULT_TITLE = '自动化测试报告'
@@ -216,7 +218,8 @@ window.onload = function(){
                            series: [{
                                         name: '测试结果',
                                         type: 'pie',    // 设置图表类型为饼图
-                                        radius: '90%%',
+                                        radius: ['30%%', '80%%'],
+                                        center: ['50%%', '50%%'],
                                         data:[          // 数据数组，name 为数据项名称，value 为数据项值
                                             {value:%(passCount)d, name:'通过', itemStyle:{color:'#4cae4c'}},
                                             {value:%(failCount)d, name:'失败', itemStyle:{color:'#d9534f'}},
@@ -233,7 +236,13 @@ window.onload = function(){
                                                 },
 　　　　　　                                          formatter: '{b}:{c}({d}%%)',
                                             }
-                                        }
+                                        },
+                                        labelLine:{
+                                            normal: {
+                                              length: 5   // show设置线是否显示，默认为true，可选值：true ¦ false
+                                            }
+
+                                        }   
                                     }]
                             };
     myChart.setOption(option_case_res);
@@ -295,8 +304,8 @@ function showCase(level) {
 		}
 	}
 	*/
-	
-	
+
+
 }
 
 function showClassDetail(cid, count) {
@@ -320,7 +329,7 @@ function showClassDetail(cid, count) {
             tid = 's' + tid0;
             tr = document.getElementById(tid);
         }
-        
+
         id_list[i] = tid;
         if(!count2){
             if (!tr.className) {
@@ -329,7 +338,7 @@ function showClassDetail(cid, count) {
             }
         }
     }
-    
+
     for (var i = 0; i < count; i++) {
         tid = id_list[i];
         //修改点击无法收起的BUG，加入【详细】切换文字变化
@@ -360,7 +369,6 @@ function html_escape(s) {
 """
     # variables: (title, generator, stylesheet, heading, report, ending)
 
-
     # ------------------------------------------------------------------------
     # Stylesheet
     #
@@ -410,14 +418,13 @@ table       { font-size: 100%; }
 %(parameters)s
 <p class='description'><strong>%(description)s</strong></p>
 </div>
-<div id="case_statistics" style="display:inline-block;width: 400px;height:200px;position: absolute;right: 120px;top:25px"></div>
+<div id="case_statistics" style="display:inline-block;width: 400px;height:250px;position: absolute;right: 120px;"></div>
 </div>
 
-""" # variables: (title, parameters, description)
+"""  # variables: (title, parameters, description)
 
     HEADING_ATTRIBUTE_TMPL = """<p class='attribute'><strong>%(name)s : </strong> %(value)s</p>
-""" # variables: (name, value)
-
+"""  # variables: (name, value)
 
     # ECHARTS_TMPL = """<div id="case_statistics" style="display:inline-block;width: 600px;height:400px;"></div>"""
 
@@ -466,7 +473,7 @@ table       { font-size: 100%; }
     <td>通过率：%(passrate)s</td>
 </tr>
 </table>
-""" # variables: (test_list, count, Pass, fail, error ,skip, passrate)
+"""  # variables: (test_list, count, Pass, fail, error ,skip, passrate)
 
     REPORT_CLASS_TMPL = r"""
 <tr class='%(style)s warning'>
@@ -478,9 +485,9 @@ table       { font-size: 100%; }
     <td class="text-center">%(skip)s</td>
     <td class="text-center"><a href="javascript:showClassDetail('%(cid)s',%(count)s)" class="detail" id='%(cid)s'>展开/收起</a></td>
 </tr>
-""" # variables: (style, desc, count, Pass, fail, error, cid)
+"""  # variables: (style, desc, count, Pass, fail, error, cid)
 
-    #失败 的样式，去掉原来JS效果，美化展示效果  -Findyou  btn-danger
+    # 失败 的样式，去掉原来JS效果，美化展示效果  -Findyou  btn-danger
     REPORT_TEST_WITH_OUTPUT_TMPL = r"""
 <tr id='%(tid)s' class='%(Class)s'>
     <td class='%(style)s'><div class='testcase'>%(desc)s</div></td>
@@ -498,7 +505,7 @@ table       { font-size: 100%; }
     </div>
     </td>
 </tr>
-""" # variables: (tid, Class, style, desc, status)
+"""  # variables: (tid, Class, style, desc, status)
 
     # 通过 的样式，加标签效果
     REPORT_TEST_NO_OUTPUT_TMPL = r"""
@@ -506,11 +513,11 @@ table       { font-size: 100%; }
     <td class='%(style)s'><div class='testcase'>%(desc)s</div></td>
     <td colspan='6' align='center'><span class="label label-success success">%(status)s</span></td>
 </tr>
-""" # variables: (tid, Class, style, desc, status)
+"""  # variables: (tid, Class, style, desc, status)
 
     REPORT_TEST_OUTPUT_TMPL = r"""
 %(id)s: %(output)s
-""" # variables: (id, output)
+"""  # variables: (id, output)
 
     # ------------------------------------------------------------------------
     # ENDING
@@ -522,11 +529,13 @@ table       { font-size: 100%; }
     </span></a></div>
     """
 
+
 # -------------------- The end of the Template class -------------------
 
 
 TestResult = unittest.TestResult
 
+
 class _TestResult(TestResult):
     # note: _TestResult is a pure representation of results.
     # It lacks the output and reporting ability compares to unittest._TextTestResult.
@@ -550,9 +559,8 @@ class _TestResult(TestResult):
         #   stack trace,
         # )
         self.result = []
-        #增加一个测试通过率 --Findyou
-        self.passrate=float(0)
-
+        # 增加一个测试通过率 --Findyou
+        self.passrate = float(0)
 
     def startTest(self, test):
         TestResult.startTest(self, test)
@@ -565,7 +573,6 @@ class _TestResult(TestResult):
         sys.stdout = stdout_redirector
         sys.stderr = stderr_redirector
 
-
     def complete_output(self):
         """
         Disconnect output redirection and return buffer.
@@ -578,14 +585,12 @@ class _TestResult(TestResult):
             self.stderr0 = None
         return self.outputBuffer.getvalue()
 
-
     def stopTest(self, test):
         # Usually one of addSuccess, addError or addFailure would have been called.
         # But there are some path in unittest that would bypass this.
         # We must disconnect stdout in stopTest(), which is guaranteed to be called.
         self.complete_output()
 
-
     def addSuccess(self, test):
         self.success_count += 1
         TestResult.addSuccess(self, test)
@@ -641,7 +646,8 @@ class _TestResult(TestResult):
 class HTMLTestRunner(Template_mixin):
     """
     """
-    def __init__(self, stream=sys.stdout, verbosity=1,title=None,description=None,tester=None):
+
+    def __init__(self, stream=sys.stdout, verbosity=1, title=None, description=None, tester=None):
         self.stream = stream
         self.verbosity = verbosity
         if title is None:
@@ -665,25 +671,24 @@ class HTMLTestRunner(Template_mixin):
         test(result)
         self.stopTime = datetime.datetime.now()
         self.generateReport(test, result)
-        print('\nTime Elapsed: %s' % (self.stopTime-self.startTime), file=sys.stderr)
+        print('\nTime Elapsed: %s' % (self.stopTime - self.startTime), file=sys.stderr)
         return result
 
-
     def sortResult(self, result_list):
         # unittest does not seems to run in any particular order.
         # Here at least we want to group them together by class.
         rmap = {}
         classes = []
-        for n,t,o,e in result_list:
+        for n, t, o, e in result_list:
             cls = t.__class__
             if cls not in rmap:
                 rmap[cls] = []
                 classes.append(cls)
-            rmap[cls].append((n,t,o,e))
+            rmap[cls].append((n, t, o, e))
         r = [(cls, rmap[cls]) for cls in classes]
         return r
 
-    #替换测试结果status为通过率 --Findyou
+    # 替换测试结果status为通过率 --Findyou
     def getReportAttributes(self, result):
         """
         Return report attributes as a list of (name, value).
@@ -692,25 +697,26 @@ class HTMLTestRunner(Template_mixin):
         startTime = str(self.startTime)[:19]
         duration = str(self.stopTime - self.startTime)[:7]
         status = []
-        status.append('总共 %s' % (result.success_count + result.failure_count + result.error_count + result.skipped_count))
-        if result.success_count: status.append('通过 %s'    % result.success_count)
+        status.append(
+            '总共 %s' % (result.success_count + result.failure_count + result.error_count + result.skipped_count))
+        if result.success_count: status.append('通过 %s' % result.success_count)
         if result.failure_count: status.append('失败 %s' % result.failure_count)
-        if result.error_count:   status.append('错误 %s'   % result.error_count  )
-        if result.skipped_count:   status.append('跳过 %s'   % result.skipped_count  )
+        if result.error_count:   status.append('错误 %s' % result.error_count)
+        if result.skipped_count:   status.append('跳过 %s' % result.skipped_count)
 
         if status:
             status = '，'.join(status)
-            self.passrate = str("%.2f%%" % (float(result.success_count) / float(result.success_count + result.failure_count + result.error_count + result.skipped_count) * 100))
+            self.passrate = str("%.2f%%" % (float(result.success_count) / float(
+                result.success_count + result.failure_count + result.error_count + result.skipped_count) * 100))
         else:
             status = 'none'
         return [
             ('测试人员', self.tester),
-            ('开始时间',startTime),
-            ('合计耗时',duration),
-            ('测试结果',status + "，通过率 "+self.passrate),
+            ('开始时间', startTime),
+            ('合计耗时', duration),
+            ('测试结果', status + "，通过率 " + self.passrate),
         ]
 
-
     def generateReport(self, test, result):
         report_attrs = self.getReportAttributes(result)
         generator = 'HTMLTestRunner %s' % __version__
@@ -720,53 +726,56 @@ class HTMLTestRunner(Template_mixin):
         report = self._generate_report(result)
         ending = self._generate_ending()
         output = self.HTML_TMPL % dict(
-            title = saxutils.escape(self.title),
-            generator = generator,
-            stylesheet = stylesheet,
-            heading = heading,
+            title=saxutils.escape(self.title),
+            generator=generator,
+            stylesheet=stylesheet,
+            heading=heading,
             # echarts = echarts,
-            report = report,
-            ending = ending,
-            passCount = result.success_count,
-            failCount = result.failure_count,
-            errorCount = result.error_count,
-            skipCount = result.skipped_count
+            report=report,
+            ending=ending,
+            passCount=result.success_count,
+            failCount=result.failure_count,
+            errorCount=result.error_count,
+            skipCount=result.skipped_count
         )
         self.stream.write(output.encode('utf8'))
 
-
     def _generate_stylesheet(self):
         return self.STYLESHEET_TMPL
 
-    #增加Tester显示 -Findyou
+    # 增加Tester显示 -Findyou
     def _generate_heading(self, report_attrs):
         a_lines = []
         for name, value in report_attrs:
             line = self.HEADING_ATTRIBUTE_TMPL % dict(
-                    name = saxutils.escape(name),
-                    value = saxutils.escape(value),
-                )
+                name=saxutils.escape(name),
+                value=saxutils.escape(value),
+            )
             a_lines.append(line)
         heading = self.HEADING_TMPL % dict(
-            title = saxutils.escape(self.title),
-            parameters = ''.join(a_lines),
-            description = saxutils.escape(self.description),
-            tester= saxutils.escape(self.tester),
+            title=saxutils.escape(self.title),
+            parameters=''.join(a_lines),
+            description=saxutils.escape(self.description),
+            tester=saxutils.escape(self.tester),
         )
         return heading
 
-    #生成报告  --Findyou添加注释
+    # 生成报告  --Findyou添加注释
     def _generate_report(self, result):
         rows = []
         sortedResult = self.sortResult(result.result)
         for cid, (cls, cls_results) in enumerate(sortedResult):
             # subtotal for a class
             np = nf = ne = nk = 0
-            for n,t,o,e in cls_results:
-                if n == 0: np += 1
-                elif n == 1: nf += 1
-                elif n == 3: nk +=1
-                else: ne += 1
+            for n, t, o, e in cls_results:
+                if n == 0:
+                    np += 1
+                elif n == 1:
+                    nf += 1
+                elif n == 3:
+                    nk += 1
+                else:
+                    ne += 1
 
             # format class description
             if cls.__module__ == "__main__":
@@ -777,45 +786,45 @@ class HTMLTestRunner(Template_mixin):
             doc = cls.__doc__ and cls.__doc__.split("\n")[1].strip() or ""
             desc = doc and '%s: %s' % (name, doc) or name
             row = self.REPORT_CLASS_TMPL % dict(
-                style = (ne > 0 and 'errorClass') or (nf > 0 and 'failClass') or (np > 0 and 'passClass') or (nk > 0 and 'skipClass'),
-                desc = desc,
-                count = np+nf+ne+nk,
-                Pass = np,
-                fail = nf,
-                error = ne,
-                skip = nk,
-                cid = 'c%s' % (cid+1),
+                style=(ne > 0 and 'errorClass') or (nf > 0 and 'failClass') or (np > 0 and 'passClass') or (
+                            nk > 0 and 'skipClass'),
+                desc=desc,
+                count=np + nf + ne + nk,
+                Pass=np,
+                fail=nf,
+                error=ne,
+                skip=nk,
+                cid='c%s' % (cid + 1),
             )
             rows.append(row)
 
-
-            for tid, (n,t,o,e) in enumerate(cls_results):
+            for tid, (n, t, o, e) in enumerate(cls_results):
                 self._generate_report_test(rows, cid, tid, n, t, o, e)
 
         report = self.REPORT_TMPL % dict(
-            test_list = ''.join(rows),
-            count = str(result.success_count+result.failure_count+result.error_count+result.skipped_count),
-            Pass = str(result.success_count),
-            fail = str(result.failure_count),
-            error = str(result.error_count),
+            test_list=''.join(rows),
+            count=str(result.success_count + result.failure_count + result.error_count + result.skipped_count),
+            Pass=str(result.success_count),
+            fail=str(result.failure_count),
+            error=str(result.error_count),
             skip=str(result.skipped_count),
-            passrate =self.passrate,
+            passrate=self.passrate,
         )
         return report
 
-
     def _generate_report_test(self, rows, cid, tid, n, t, o, e):
         # e.g. 'pt1.1', 'ft1.1', etc
         has_output = bool(o or e)
         # ID修改点为下划线,支持Bootstrap折叠展开特效
-        tid = ((n==0 and 'p') or (n==1 and 'f') or (n==3 and 's') or (n==2 and 'e')) + 't%s_%s' % (cid+1,tid+1)
+        tid = ((n == 0 and 'p') or (n == 1 and 'f') or (n == 3 and 's') or (n == 2 and 'e')) + 't%s_%s' % (
+        cid + 1, tid + 1)
         name = t.id().split('.')[-1]
         doc = t.shortDescription() or ""
         desc = doc and ('%s: %s' % (name, doc)) or name
         tmpl = has_output and self.REPORT_TEST_WITH_OUTPUT_TMPL or self.REPORT_TEST_NO_OUTPUT_TMPL
         # utf-8 支持中文 - Findyou
 
-         # o and e should be byte string because they are collected from stdout and stderr?
+        # o and e should be byte string because they are collected from stdout and stderr?
         if isinstance(o, str):
             # TODO: some problem with 'string_escape': it escape \n and mess up formating
             # uo = unicode(o.encode('string_escape'))
@@ -832,18 +841,19 @@ class HTMLTestRunner(Template_mixin):
             ue = e
 
         script = self.REPORT_TEST_OUTPUT_TMPL % dict(
-            id = tid,
-            output = saxutils.escape(uo+ue),
+            id=tid,
+            output=saxutils.escape(uo + ue),
         )
 
         row = tmpl % dict(
-            tid = tid,
-            Class = (n == 0 and 'hiddenRow' or ''),
-            style = (n == 2 and 'errorCase') or (n == 1 and 'failCase') or (n == 0 and 'passCase') or (n == 3 and 'skipCase'),
-            desc = desc,
-            script = script,
-            status = self.STATUS[n],
-            btn_type = (n == 1 and 'btn-danger') or (n == 2 and 'btn-warning') or (n == 3 and 'skip_btn')
+            tid=tid,
+            Class=(n == 0 and 'hiddenRow' or ''),
+            style=(n == 2 and 'errorCase') or (n == 1 and 'failCase') or (n == 0 and 'passCase') or (
+                        n == 3 and 'skipCase'),
+            desc=desc,
+            script=script,
+            status=self.STATUS[n],
+            btn_type=(n == 1 and 'btn-danger') or (n == 2 and 'btn-warning') or (n == 3 and 'skip_btn')
         )
         rows.append(row)
         if not has_output:
@@ -852,8 +862,9 @@ class HTMLTestRunner(Template_mixin):
     def _generate_ending(self):
         return self.ENDING_TMPL
 
-   # def _generate_echarts(self):
-   #     return self.ECHARTS_TMPL
+
+# def _generate_echarts(self):
+#     return self.ECHARTS_TMPL
 
 ##############################################################################
 # Facilities for running tests from the command line
@@ -867,6 +878,7 @@ class TestProgram(unittest.TestProgram):
     A variation of the unittest.TestProgram. Please refer to the base
     class for command line parameters.
     """
+
     def runTests(self):
         # Pick HTMLTestRunner as the default test runner.
         # base class's testRunner parameter is not useful because it means
@@ -875,6 +887,7 @@ class TestProgram(unittest.TestProgram):
             self.testRunner = HTMLTestRunner(verbosity=self.verbosity)
         unittest.TestProgram.runTests(self)
 
+
 main = TestProgram
 
 ##############################################################################
